==> apache-linkis-1.3.2-src.tar.gz: apache-linkis-1.3.2-src/linkis-computation-governance/linkis-entrance/src/main/scala/org/apache/linkis/entrance/execute/impl/EntranceExecutorManagerImpl.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.entrance.execute.impl

import org.apache.linkis.entrance.execute._
import org.apache.linkis.orchestrator.ecm.EngineConnManager
import org.apache.linkis.scheduler.listener.ExecutorListener
import org.apache.linkis.scheduler.queue.GroupFactory

class EntranceExecutorManagerImpl(groupFactory: GroupFactory, engineConnManager: EngineConnManager)
    extends EntranceExecutorManager(groupFactory) {

  override def getOrCreateInterceptors(): Array[ExecuteRequestInterceptor] = Array(
    JobExecuteRequestInterceptor,
    LabelExecuteRequestInterceptor,
    ReconnectExecuteRequestInterceptor,
    StorePathExecuteRequestInterceptor,
    RuntimePropertiesExecuteRequestInterceptor
  )

  override def setExecutorListener(engineListener: ExecutorListener): Unit = {}
}

==> apache-linkis-1.8.0-src.tar.gz: apache-linkis-1.8.0-src/linkis-computation-governance/linkis-entrance/src/main/scala/org/apache/linkis/entrance/execute/impl/EntranceExecutorManagerImpl.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.entrance.execute.impl

import org.apache.linkis.entrance.execute._
import org.apache.linkis.orchestrator.ecm.EngineConnManager
import org.apache.linkis.scheduler.listener.ExecutorListener
import org.apache.linkis.scheduler.queue.GroupFactory

class EntranceExecutorManagerImpl(groupFactory: GroupFactory)
    extends EntranceExecutorManager(groupFactory) {

  override def getOrCreateInterceptors(): Array[ExecuteRequestInterceptor] = Array(
    JobExecuteRequestInterceptor,
    LabelExecuteRequestInterceptor,
    ReconnectExecuteRequestInterceptor,
    StorePathExecuteRequestInterceptor,
    RuntimePropertiesExecuteRequestInterceptor
  )

  override def setExecutorListener(engineListener: ExecutorListener): Unit = {}
}
